@@ -1,3 +1,5 @@
+#![no_std]
+
 //! An embedded-hal driver for the GP2D12 infrared distance sensor.
 //!
 //! Distance calibration is based on the values in the
@@ -12,7 +14,7 @@
 //! #     common::Generic,
 //! #     MockError,
 //! # };
-//! # let expectations: [Transaction<u16>; 1] = [Transaction::read(0, 950)];
+//! # let expectations: [Transaction<u32>; 1] = [Transaction::read(0, 950)];
 //! # let mut adc = Mock::new(&expectations);
 //! # let pin = MockChan0 {};
 //!
@@ -22,6 +24,11 @@
 //! // measuring 40 cm
 //! assert_eq!(gp2d12.distance(&mut adc), Ok(Some(40)));
 //! ```
+//!
+//! See the [STM32F3Discovery
+//! example](https://github.com/peterstuart/gp2d12/blob/main/examples/stm32f3discovery/README.md)
+//! for a complete example.
+
 mod gp2d12;
 
 pub use self::gp2d12::Gp2d12;
